pub struct PublishRequest {
pub destination: AccountAddress,
pub bundle: ModuleBundle,
pub expected_modules: BTreeSet<String>,
pub check_compat: bool,
}Expand description
Represents a request for code publishing made from a native call and to be processed by the Aptos VM.
Fields
destination: AccountAddressbundle: ModuleBundleexpected_modules: BTreeSet<String>check_compat: boolAuto Trait Implementations
impl RefUnwindSafe for PublishRequest
impl Send for PublishRequest
impl Sync for PublishRequest
impl Unpin for PublishRequest
impl UnwindSafe for PublishRequest