Structs

The native code context.

The PackakeMetadata type.

The package registry at the given address.

Represents a request for code publishing made from a native call and to be processed by the Aptos VM.

Functions